﻿/*
Copyright (c) 2013, Douglas Stebila, Brendon Park, David Sweeney, Nathan Wills, Simon Lockhart, Thomas Phan
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice, this
  list of conditions and the following disclaimer in the documentation and/or
  other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
using System;
using System.IO;
using System.Security.Cryptography;

namespace NMLE.RCE
{
    /// <summary>
    ///     Rolling TransformKey, Convergent Encryption
    ///     Message locked encryption implementation providing single pass
    ///     MLE using rolling keying. 
    /// </summary>
    /// <typeparam name="THashAlgorithm">
    ///     The hash algorythm used to produce the keys used to encrypt the
    ///     message.
    /// </typeparam>
    /// <typeparam name="TEncryptionAlgorithm">
    ///     The cryptographic algorytm used to produce the cyphertext.
    /// </typeparam>
    public sealed class RCE<THashAlgorithm,TEncryptionAlgorithm>
        : MessageLockedAlgoritm<THashAlgorithm, TEncryptionAlgorithm>
        where THashAlgorithm : HashAlgorithm, new()
        where TEncryptionAlgorithm : SymmetricAlgorithm, new()
    {

        /// <summary>
        ///     Creates a message locked decryptor object with the current
        ///     key, hash algorythm and, symetric algorythm.
        /// </summary>
        /// <returns>
        ///     A message locked decryptor object.
        /// </returns>
        public override ICryptoTransform GetDecryptor()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        ///     Creates a message locked encryptor object with the current
        ///     hash algorythm and symetric algorythm.
        /// </summary>
        /// <returns>
        /// </returns>
        public override ICryptoTransform GetEncryptor()
        {
            throw new NotImplementedException();
        }

        public override void DeriveKey(Stream message, int keySize)
        {
            throw new NotImplementedException();
        }

        public override void DeriveKey(Stream message)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        ///     Gets the key produced by the Encryptor
        /// </summary>
        public override byte[] Key
        {
            get { throw new NotImplementedException(); }
            set { throw new NotImplementedException(); }
        }

        public override byte[] Tag
        {
            get { throw new NotImplementedException(); }
            protected set { throw new NotImplementedException(); }
        }
    }
}
