﻿/*
Copyright (c) 2013, Douglas Stebila, Brendon Park, David Sweeney, Nathan Wills, Simon Lockhart, Thomas Phan
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice, this
  list of conditions and the following disclaimer in the documentation and/or
  other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
using System;
using System.IO;
using System.Security.Cryptography;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using NMLE.HCE;

namespace NMLE.Test
{
    [TestClass]
    public class TestDeriveKeyRIPEMD160 : MLETestBase
    {
        [ClassInitialize]
        public static void Setup(TestContext context)
        {
            var buffer = new byte[819200];
            new Random().NextBytes(buffer);
            TestMessageStream = new MemoryStream(buffer);
        }

        [TestMethod]
        public void TestHCEDeriveKeyWithRIPEMD160AndAES()
        {
            var test = new HCE<RIPEMD160Managed, AesManaged>();
            var result = TestDeriveKey<RIPEMD160Managed>(test);
            Assert.IsTrue(
                result == KeyDerivationResults.OK,
                "Key derivation error code: " + result
                );
        }

        [TestMethod]
        public void TestHCEDeriveKeyWithRIPEMD160AndDES()
        {
            var test = new HCE<RIPEMD160Managed, DESCryptoServiceProvider>();
            var result = TestDeriveKey<RIPEMD160Managed>(test);
            Assert.IsTrue(
                result == KeyDerivationResults.OK,
                "Key derivation error code: " + result
                );
        }
        [TestMethod]
        public void TestHCEDeriveKeyWithRIPEMD160AndRC2()
        {
            var test = new HCE<RIPEMD160Managed, RC2CryptoServiceProvider>();
            var result = TestDeriveKey<RIPEMD160Managed>(test);
            Assert.IsTrue(
                result == KeyDerivationResults.OK,
                "Key derivation error code: " + result
                );
        }

        [TestMethod]
        public void TestHCEDeriveKeyWithRIPEMD160AndRijndael()
        {
            var test = new HCE<RIPEMD160Managed, RijndaelManaged>();
            var result = TestDeriveKey<RIPEMD160Managed>(test);
            Assert.IsTrue(
                result == KeyDerivationResults.OK,
                "Key derivation error code: " + result
                );
        }

        //[TestMethod] Tripple DES not supported!
        public void TestHCEDeriveKeyWithRIPEMD160AndTripleDES()
        {
            var test = new HCE<RIPEMD160Managed, TripleDESCryptoServiceProvider>();
            var result = TestDeriveKey<RIPEMD160Managed>(test);
            Assert.IsTrue(
                result == KeyDerivationResults.OK,
                "Key derivation error code: " + result
                );
        }
    }
}
