﻿/*
Copyright (c) 2013, Douglas Stebila, Brendon Park, David Sweeney, Nathan Wills, Simon Lockhart, Thomas Phan
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice, this
  list of conditions and the following disclaimer in the documentation and/or
  other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
using System;
using System.IO;
using System.Linq;
using System.Security.Cryptography;

namespace NMLE.Test
{
    public abstract class MLETestBase
    {
        public static Stream TestMessageStream;

        public void TestMLEAlgorythmEncrypt(
            IMessageLockedAlgorithm test
            )
        {
            TestMessageStream.Position = 0;

            test.DeriveKey(TestMessageStream);

            TestMessageStream.Position = 0;

            var hceEncryptor = test.GetEncryptor();
            var hceDecryptor = test.GetDecryptor();

            var decryptedStream = new MemoryStream();
            var encryptedStream = new MemoryStream();
            var testStream = new MemoryStream();

            TestMessageStream.CopyTo(testStream);
            testStream.Position = 0;

            var encStream = new CryptoStream(
                encryptedStream,
                hceEncryptor,
                CryptoStreamMode.Write
                );

            TestMessageStream.CopyTo(encStream);
            encStream.FlushFinalBlock();
            encryptedStream.Position = 0;

            var decStream = new CryptoStream(
                encryptedStream,
                hceDecryptor,
                CryptoStreamMode.Read
                );

            decStream.CopyTo(decryptedStream);

            decryptedStream.ToArray().SequenceEqual(
                    ((MemoryStream) TestMessageStream).ToArray()
                    );
        }

        public enum KeyDerivationResults
        {
            OK,
            NullKey,
            IncorectLength,
            KeyHashMismatch
        }

        public KeyDerivationResults TestDeriveKey<THashAlgorythm>(
            IMessageLockedAlgorithm test
            ) where THashAlgorythm : HashAlgorithm, new()
        {
            var comparisonHash = new THashAlgorythm().ComputeHash(
                TestMessageStream
                );

            TestMessageStream.Position = 0;
            test.DeriveKey(TestMessageStream);

            if (test.Key == null)
                return KeyDerivationResults.NullKey;

            if (test.Key.Length != test.LargestValidKey()/8)
                return KeyDerivationResults.IncorectLength;

            return HashMatchesKey(comparisonHash, test.Key)
                ? KeyDerivationResults.OK
                : KeyDerivationResults.KeyHashMismatch;
        }

        public Boolean HashMatchesKey(byte[] hash, byte[] key)
        {
            if (hash.Length < key.Length)
                return false;

            for (int i = 0 ; i<key.Length;i++)
                if (hash[i] != key[i])
                    return false;
            return true;
        }

    }
}
