﻿/*
Copyright (c) 2013, Douglas Stebila, Brendon Park, David Sweeney, Nathan Wills, Simon Lockhart, Thomas Phan
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice, this
  list of conditions and the following disclaimer in the documentation and/or
  other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
using System;
using System.IO;
using System.Security.Cryptography;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using NMLE.HCE;

namespace NMLE.Test
{
    [TestClass]
    public class TestMessageLockedCrypto : MLETestBase
    {

        [ClassInitialize]
        public static void Setup(TestContext context)
        {
            var buffer = new byte[128];
            new Random().NextBytes(buffer);
            TestMessageStream = new MemoryStream(buffer);
        }


        [TestMethod]
        public void TestHCEConstructorWithSHA1AndRijndael()
        {
            var test = new HCE<SHA1Managed, RijndaelManaged>();
            var reference = new RijndaelManaged();
            Assert.IsNotNull(test);
            Assert.IsTrue(
                test.BlockSize == reference.BlockSize,
                "Block sizes do not match " + test.BlockSize + "!=" +
                reference.BlockSize
                );
            Assert.IsTrue(
                test.FeedbackSize == reference.FeedbackSize,
                "Feedback sizes do not match"
                );
            Assert.IsTrue(
                test.Mode == reference.Mode,
                "Mode does not match"
                );
            Assert.IsTrue(
                test.Padding == reference.Padding,
                "Padding does not match"
                );
        }

        [TestMethod]
        public void TestHCEConstructorWithMD5AndDES()
        {
            var test = new HCE<MD5CryptoServiceProvider, DESCryptoServiceProvider>();
            var reference = new DESCryptoServiceProvider();

            Assert.IsNotNull(test);

            Assert.IsTrue(
                test.BlockSize == reference.BlockSize,
                "Block sizes do not match " + test.BlockSize + "!=" +
                reference.BlockSize
                );
            Assert.IsTrue(
                test.FeedbackSize == reference.FeedbackSize,
                "Feedback sizes do not match"
                );
            Assert.IsTrue(
                test.Mode == reference.Mode,
                "Mode does not match"
                );
            Assert.IsTrue(
                test.Padding == reference.Padding,
                "Padding does not match"
                );

        }
    }
}
